@@ -1,12 +1,14 @@
 package Email::Send::Qmail;
-# $Id: Qmail.pm,v 1.3 2005/05/11 03:01:25 cwest Exp $
+# $Id: Qmail.pm,v 1.4 2006/01/17 22:10:55 cwest Exp $
 use strict;
 
-use vars qw[$QMAIL];
+use vars qw[$QMAIL $VERSION];
 $QMAIL   ||= q[qmail-inject];
 
 use Return::Value;
 
+$VERSION   = '2.01';
+
 sub is_available {
     return   `which $QMAIL`
            ? success
