@@ -1,16 +1,26 @@
 package Email::Send::Sendmail;
-# $Id: Sendmail.pm,v 1.3 2004/07/20 22:11:46 cwest Exp $
+# $Id: Sendmail.pm,v 1.5 2006/01/17 22:10:55 cwest Exp $
 use strict;
 
-use vars qw[$VERSION $SENDMAIL];
-$VERSION  = (qw$Revision: 1.3 $)[1];
+use Return::Value;
+
+use vars qw[$SENDMAIL $VERSION];
 $SENDMAIL ||= q[sendmail];
 
+$VERSION   = '2.01';
+
+sub is_available {
+    return   `which $SENDMAIL`
+           ? success
+           : failure;
+}
+
 sub send {
-    my ($message, @args) = @_;
-    open SENDMAIL, "| $SENDMAIL -t -oi @args" or return undef;
+    my ($class, $message, @args) = @_;
+    open SENDMAIL, "| $SENDMAIL -t -oi @args" or return failure;
     print SENDMAIL $message->as_string;
     close SENDMAIL;
+    return success;
 }
 
 1;
@@ -25,7 +35,7 @@ Email::Send::Sendmail - Send Messages using sendmail
 
   use Email::Send;
 
-  send Sendmail => $message;
+  Email::Send->new({mailer => 'Sendmail'})->send($message);
 
 =head1 DESCRIPTION
 
